summary,lavacreg-method: Summary of a lavacreg object
Description
Exports the parameter table with parameter estimates and standard errors
for an estimated latent variable count regression model.
Usage
# S4 method for lavacreg
summary(object)
Value
Function prints the parameter table of an estimated model, which
includes the parameter estimates and standard errors.
Arguments
- object
lavacreg object